Struct Channel
pub struct Channel {
framed: Framed<TcpStream, ObjectCodec>,
version: Version,
}Expand description
A channel to a gpsd server.
The channel acts as a [Sink] for Commands and a [Stream] of
Objects.
See the module documentation for more information.
Fields
framed: Framed<TcpStream, ObjectCodec>version: VersionImplementations
impl Channel
impl Channel
pub async fn connect_localhost() -> Result<Self, Error>
pub async fn connect_localhost() -> Result<Self, Error>
Connects to a gpsd server running on localhost with the default port.
Errors
Returns an error if the connection or gpsd handshake fails.
pub async fn connect(addr: impl ToSocketAddrs) -> Result<Self, Error>
pub async fn connect(addr: impl ToSocketAddrs) -> Result<Self, Error>
Connects to a gpsd server at the given address.
Errors
Returns an error if the connection or gpsd handshake fails.
async fn connect_stream(stream: TcpStream) -> Result<Self, Error>
async fn connect_stream(stream: TcpStream) -> Result<Self, Error>
Connects to a gpsd server over an existing TcpStream.